Skip to contents

Show an organization

Usage

organization_show(
  id,
  include_datasets = FALSE,
  include_users = TRUE,
  url = get_default_url(),
  key = get_default_key(),
  as = "list",
  ...
)

Arguments

id

(character) Organization id or name.

include_datasets

(logical). Include a list of the organization datasets.

include_users

(logical) Include the organization's users. CKAN 2.12 changed the server default to FALSE regardless of the ckan.auth.public_user_details setting (https://github.com/ckan/ckan/pull/9232); ckanr defaults to TRUE to preserve the historical behavior. The parameter is accepted on all supported CKAN versions (2.9, 2.10, 2.11, 2.12).

url

Base URL to use. Default: https://demo.ckan.org/. See also ckanr_setup and get_default_url.

key

A privileged CKAN API key. Default: your key set with ckanr_setup

as

(character) One of list (default), table, or json. Parsing with the table option uses jsonlite::fromJSON(..., simplifyDataFrame = TRUE), which attempts to parse data to data.frame's when possible. The result can vary from a vector, list or data.frame. (required)

...

Extra curl arguments. The function passes them to verb-POST (optional)

Details

By default the function drops the help and success slots. It returns only the result slot. If you want raw json, request as = 'json'. Then you parse the result yourself to get the help slot.

Examples

if (FALSE) { # \dontrun{
ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))

res <- organization_create("stuffthings2")
organization_show(res$id)
} # }