Return a list of tag names that contain a query string. See https://docs.ckan.org/en/latest/api/ for the official API contract.
Usage
tag_autocomplete(
q,
vocabulary_id = NULL,
url = get_default_url(),
key = get_default_key(),
as = "list",
...
)Arguments
- q
(character) Partial string to search for. The function returns entries whose name or title contains this string. (required)
- vocabulary_id
(character) The function restricts matches to this vocabulary.
- url
Base URL to use. Default: https://demo.ckan.org/. See also
ckanr_setupandget_default_url.- key
A privileged CKAN API key. Default: your key set with
ckanr_setup- as
(character) One of list (default), table, or json. Parsing with the table option uses
jsonlite::fromJSON(..., simplifyDataFrame = TRUE), which attempts to parse data to data.frame's when possible. The result can vary from a vector, list or data.frame. (required)- ...
Extra curl arguments. The function passes them to
verb-POST(optional)