Skip to contents

Search tags.

Usage

tag_search(
  query = NULL,
  vocabulary_id = NULL,
  offset = 0,
  limit = 31,
  url = get_default_url(),
  key = get_default_key(),
  as = "list",
  ...
)

Arguments

query

(character) Tag name query to search for. If you give a query, the function returns only tags whose names contain this string. The value is one or more search strings.

vocabulary_id

(character) ID or name of a vocabulary. If you give a vocabulary, the function returns only tags that belong to this vocabulary.

offset

(numeric) Where to start getting activity items from (optional, default: 0)

limit

(numeric) The maximum number of activities to return (optional, default: 31)

url

Base URL to use. Default: https://demo.ckan.org/. See also ckanr_setup and get_default_url.

key

A privileged CKAN API key. Default: your key set with ckanr_setup

as

(character) One of list (default), table, or json. Parsing with the table option uses jsonlite::fromJSON(..., simplifyDataFrame = TRUE), which attempts to parse data to data.frame's when possible. The result can vary from a vector, list or data.frame. (required)

...

Extra curl arguments. The function passes them to verb-POST (optional)

Examples

if (FALSE) { # \dontrun{
tag_search(query = "ta")
tag_search(query = c("ta", "al"))

# different formats back
tag_search(query = "ta", as = "json")
tag_search(query = "ta", as = "table")
} # }