Skip to contents

Return a list of user names that contain a query string. See https://docs.ckan.org/en/2.11/api/#ckan.logic.action.get.user_autocomplete for the official API contract.

Usage

user_autocomplete(
  q,
  limit = 20,
  url = get_default_url(),
  key = get_default_key(),
  as = "list",
  ...
)

Arguments

q

(character) Partial string to search for. The function returns entries whose name or title contains this string. (required)

limit

(numeric) The maximum number of user names to return. Default: 20 (optional)

url

Base URL to use. Default: https://demo.ckan.org/. See also ckanr_setup and get_default_url.

key

A privileged CKAN API key. Default: your key set with ckanr_setup

as

(character) One of list (default), table, or json. Parsing with the table option uses jsonlite::fromJSON(..., simplifyDataFrame = TRUE), which attempts to parse data to data.frame's when possible. The result can vary from a vector, list or data.frame. (required)

...

Extra curl arguments. The function passes them to verb-POST (optional)

Value

A list of user dictionaries, each with the keys name, fullname, and id. With as = "table", a data.frame; with as = "json", the raw JSON response.

References

https://docs.ckan.org/en/2.11/api/#ckan.logic.action.get.user_autocomplete

Examples

if (FALSE) { # \dontrun{
ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))

user_autocomplete(q = "admin")
} # }