Number of new activities of an authorized user
Usage
dashboard_count(
url = get_default_url(),
key = get_default_key(),
as = "list",
...
)Arguments
- url
Base URL to use. Default: https://demo.ckan.org/. See also
ckanr_setupandget_default_url.- key
A privileged CKAN API key. Default: your key set with
ckanr_setup- as
(character) One of list (default), table, or json. Parsing with the table option uses
jsonlite::fromJSON(..., simplifyDataFrame = TRUE), which attempts to parse data to data.frame's when possible. The result can vary from a vector, list or data.frame. (required)- ...
Extra curl arguments. The function passes them to
verb-POST(optional)
Details
CKAN does not count activities from the user herself, but they appear in the dashboard. Users do not want notices about things they did themselves.
Examples
if (FALSE) { # \dontrun{
# Setup
ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
# count
dashboard_new_activities_count()
} # }