List tags.
Usage
tag_list(
query = NULL,
vocabulary_id = NULL,
all_fields = FALSE,
url = get_default_url(),
key = get_default_key(),
as = "list",
...
)Arguments
- query
(character) Tag name query to search for. If you give a query, the function returns only tags whose names contain this string.
- vocabulary_id
(character) ID or name of a vocabulary. If you give a vocabulary, the function returns only tags that belong to this vocabulary.
- all_fields
(logical) The function returns full tag dictionaries instead of names. Default is
FALSE.- url
Base URL to use. Default: https://demo.ckan.org/. See also
ckanr_setupandget_default_url.- key
A privileged CKAN API key. Default: your key set with
ckanr_setup- as
(character) One of list (default), table, or json. Parsing with the table option uses
jsonlite::fromJSON(..., simplifyDataFrame = TRUE), which attempts to parse data to data.frame's when possible. The result can vary from a vector, list or data.frame. (required)- ...
Extra curl arguments. The function passes them to
verb-POST(optional)